@@ -14,7 +14,15 @@ extern void eel_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* BOOLEAN:POINTER,POINTER (eelmarshal.list:2) */
+/* BOOLEAN:BOOLEAN (eelmarshal.list:2) */
+extern void eel_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
+                                          GValue       *return_value,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint,
+                                          gpointer      marshal_data);
+
+/* BOOLEAN:POINTER,POINTER (eelmarshal.list:3) */
 extern void eel_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -22,7 +30,15 @@ extern void eel_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* BOOLEAN:INT,POINTER,INT,INT,UINT (eelmarshal.list:3) */
+/* BOOLEAN:VOID (eelmarshal.list:4) */
+extern void eel_marshal_BOOLEAN__VOID (GClosure     *closure,
+                                       GValue       *return_value,
+                                       guint         n_param_values,
+                                       const GValue *param_values,
+                                       gpointer      invocation_hint,
+                                       gpointer      marshal_data);
+
+/* BOOLEAN:INT,POINTER,INT,INT,UINT (eelmarshal.list:5) */
 extern void eel_marshal_BOOLEAN__INT_POINTER_INT_INT_UINT (GClosure     *closure,
                                                            GValue       *return_value,
                                                            guint         n_param_values,
@@ -30,7 +46,7 @@ extern void eel_marshal_BOOLEAN__INT_POINTER_INT_INT_UINT (GClosure     *closure
                                                            gpointer      invocation_hint,
                                                            gpointer      marshal_data);
 
-/* ENUM:INT,INT (eelmarshal.list:4) */
+/* ENUM:INT,INT (eelmarshal.list:6) */
 extern void eel_marshal_ENUM__INT_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -38,7 +54,7 @@ extern void eel_marshal_ENUM__INT_INT (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* INT:POINTER,STRING (eelmarshal.list:5) */
+/* INT:POINTER,STRING (eelmarshal.list:7) */
 extern void eel_marshal_INT__POINTER_STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -46,7 +62,7 @@ extern void eel_marshal_INT__POINTER_STRING (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* INT:VOID (eelmarshal.list:6) */
+/* INT:VOID (eelmarshal.list:8) */
 extern void eel_marshal_INT__VOID (GClosure     *closure,
                                    GValue       *return_value,
                                    guint         n_param_values,
@@ -54,7 +70,7 @@ extern void eel_marshal_INT__VOID (GClosure     *closure,
                                    gpointer      invocation_hint,
                                    gpointer      marshal_data);
 
-/* POINTER:INT (eelmarshal.list:7) */
+/* POINTER:INT (eelmarshal.list:9) */
 extern void eel_marshal_POINTER__INT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
@@ -62,7 +78,7 @@ extern void eel_marshal_POINTER__INT (GClosure     *closure,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
 
-/* POINTER:INT,INT,POINTER,POINTER (eelmarshal.list:8) */
+/* POINTER:INT,INT,POINTER,POINTER (eelmarshal.list:10) */
 extern void eel_marshal_POINTER__INT_INT_POINTER_POINTER (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
@@ -70,7 +86,7 @@ extern void eel_marshal_POINTER__INT_INT_POINTER_POINTER (GClosure     *closure,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);
 
-/* POINTER:POINTER (eelmarshal.list:9) */
+/* POINTER:POINTER (eelmarshal.list:11) */
 extern void eel_marshal_POINTER__POINTER (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -78,7 +94,7 @@ extern void eel_marshal_POINTER__POINTER (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* POINTER:POINTER,INT (eelmarshal.list:10) */
+/* POINTER:POINTER,INT (eelmarshal.list:12) */
 extern void eel_marshal_POINTER__POINTER_INT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -86,7 +102,7 @@ extern void eel_marshal_POINTER__POINTER_INT (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* POINTER:POINTER,INT,INT,POINTER,POINTER (eelmarshal.list:11) */
+/* POINTER:POINTER,INT,INT,POINTER,POINTER (eelmarshal.list:13) */
 extern void eel_marshal_POINTER__POINTER_INT_INT_POINTER_POINTER (GClosure     *closure,
                                                                   GValue       *return_value,
                                                                   guint         n_param_values,
@@ -94,7 +110,7 @@ extern void eel_marshal_POINTER__POINTER_INT_INT_POINTER_POINTER (GClosure     *
                                                                   gpointer      invocation_hint,
                                                                   gpointer      marshal_data);
 
-/* POINTER:POINTER,INT,INT,STRING,POINTER (eelmarshal.list:12) */
+/* POINTER:POINTER,INT,INT,STRING,POINTER (eelmarshal.list:14) */
 extern void eel_marshal_POINTER__POINTER_INT_INT_STRING_POINTER (GClosure     *closure,
                                                                  GValue       *return_value,
                                                                  guint         n_param_values,
@@ -102,7 +118,7 @@ extern void eel_marshal_POINTER__POINTER_INT_INT_STRING_POINTER (GClosure     *c
                                                                  gpointer      invocation_hint,
                                                                  gpointer      marshal_data);
 
-/* POINTER:POINTER,POINTER (eelmarshal.list:13) */
+/* POINTER:POINTER,POINTER (eelmarshal.list:15) */
 extern void eel_marshal_POINTER__POINTER_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -110,7 +126,7 @@ extern void eel_marshal_POINTER__POINTER_POINTER (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* POINTER:POINTER,POINTER,POINTER (eelmarshal.list:14) */
+/* POINTER:POINTER,POINTER,POINTER (eelmarshal.list:16) */
 extern void eel_marshal_POINTER__POINTER_POINTER_POINTER (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
@@ -118,7 +134,7 @@ extern void eel_marshal_POINTER__POINTER_POINTER_POINTER (GClosure     *closure,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);
 
-/* POINTER:POINTER,STRING,POINTER (eelmarshal.list:15) */
+/* POINTER:POINTER,STRING,POINTER (eelmarshal.list:17) */
 extern void eel_marshal_POINTER__POINTER_STRING_POINTER (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -126,7 +142,7 @@ extern void eel_marshal_POINTER__POINTER_STRING_POINTER (GClosure     *closure,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);
 
-/* STRING:POINTER (eelmarshal.list:16) */
+/* STRING:POINTER (eelmarshal.list:18) */
 extern void eel_marshal_STRING__POINTER (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -134,7 +150,7 @@ extern void eel_marshal_STRING__POINTER (GClosure     *closure,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
 
-/* STRING:POINTER,INT (eelmarshal.list:17) */
+/* STRING:POINTER,INT (eelmarshal.list:19) */
 extern void eel_marshal_STRING__POINTER_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -142,7 +158,7 @@ extern void eel_marshal_STRING__POINTER_INT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* STRING:POINTER,POINTER (eelmarshal.list:18) */
+/* STRING:POINTER,POINTER (eelmarshal.list:20) */
 extern void eel_marshal_STRING__POINTER_POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -150,7 +166,7 @@ extern void eel_marshal_STRING__POINTER_POINTER (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* STRING:POINTER,POINTER,POINTER (eelmarshal.list:19) */
+/* STRING:POINTER,POINTER,POINTER (eelmarshal.list:21) */
 extern void eel_marshal_STRING__POINTER_POINTER_POINTER (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -158,7 +174,7 @@ extern void eel_marshal_STRING__POINTER_POINTER_POINTER (GClosure     *closure,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);
 
-/* STRING:POINTER,POINTER,STRING (eelmarshal.list:20) */
+/* STRING:POINTER,POINTER,STRING (eelmarshal.list:22) */
 extern void eel_marshal_STRING__POINTER_POINTER_STRING (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -166,7 +182,7 @@ extern void eel_marshal_STRING__POINTER_POINTER_STRING (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* STRING:POINTER,STRING (eelmarshal.list:21) */
+/* STRING:POINTER,STRING (eelmarshal.list:23) */
 extern void eel_marshal_STRING__POINTER_STRING (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -174,7 +190,7 @@ extern void eel_marshal_STRING__POINTER_STRING (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* STRING:VOID (eelmarshal.list:22) */
+/* STRING:VOID (eelmarshal.list:24) */
 extern void eel_marshal_STRING__VOID (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
@@ -182,7 +198,7 @@ extern void eel_marshal_STRING__VOID (GClosure     *closure,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
 
-/* VOID:BOXED,BOXED (eelmarshal.list:23) */
+/* VOID:BOXED,BOXED (eelmarshal.list:25) */
 extern void eel_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -190,7 +206,7 @@ extern void eel_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:INT,POINTER,INT,INT,UINT (eelmarshal.list:24) */
+/* VOID:INT,POINTER,INT,INT,UINT (eelmarshal.list:26) */
 extern void eel_marshal_VOID__INT_POINTER_INT_INT_UINT (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -198,7 +214,7 @@ extern void eel_marshal_VOID__INT_POINTER_INT_INT_UINT (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* VOID:INT,INT (eelmarshal.list:25) */
+/* VOID:INT,INT (eelmarshal.list:27) */
 extern void eel_marshal_VOID__INT_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -206,7 +222,7 @@ extern void eel_marshal_VOID__INT_INT (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* VOID:INT,INT,BOXED (eelmarshal.list:26) */
+/* VOID:INT,INT,BOXED (eelmarshal.list:28) */
 extern void eel_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -214,7 +230,7 @@ extern void eel_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:INT,INT,INT,INT (eelmarshal.list:27) */
+/* VOID:INT,INT,INT,INT (eelmarshal.list:29) */
 extern void eel_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -222,10 +238,10 @@ extern void eel_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* VOID:OBJECT (eelmarshal.list:28) */
+/* VOID:OBJECT (eelmarshal.list:30) */
 #define eel_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
 
-/* VOID:OBJECT,POINTER (eelmarshal.list:29) */
+/* VOID:OBJECT,POINTER (eelmarshal.list:31) */
 extern void eel_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -233,7 +249,7 @@ extern void eel_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT (eelmarshal.list:30) */
+/* VOID:OBJECT,OBJECT (eelmarshal.list:32) */
 extern void eel_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -241,7 +257,7 @@ extern void eel_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER,POINTER,POINTER,INT,INT,UINT (eelmarshal.list:31) */
+/* VOID:POINTER,POINTER,POINTER,POINTER,INT,INT,UINT (eelmarshal.list:33) */
 extern void eel_marshal_VOID__POINTER_POINTER_POINTER_POINTER_INT_INT_UINT (GClosure     *closure,
                                                                             GValue       *return_value,
                                                                             guint         n_param_values,
@@ -249,7 +265,7 @@ extern void eel_marshal_VOID__POINTER_POINTER_POINTER_POINTER_INT_INT_UINT (GClo
                                                                             gpointer      invocation_hint,
                                                                             gpointer      marshal_data);
 
-/* VOID:POINTER,STRING,STRING (eelmarshal.list:32) */
+/* VOID:POINTER,STRING,STRING (eelmarshal.list:34) */
 extern void eel_marshal_VOID__POINTER_STRING_STRING (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
@@ -257,7 +273,7 @@ extern void eel_marshal_VOID__POINTER_STRING_STRING (GClosure     *closure,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER,POINTER (eelmarshal.list:33) */
+/* VOID:POINTER,POINTER,POINTER (eelmarshal.list:35) */
 extern void eel_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
@@ -265,7 +281,7 @@ extern void eel_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);
 
-/* VOID:POINTER,STRING (eelmarshal.list:34) */
+/* VOID:POINTER,STRING (eelmarshal.list:36) */
 extern void eel_marshal_VOID__POINTER_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -273,7 +289,7 @@ extern void eel_marshal_VOID__POINTER_STRING (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:POINTER,INT (eelmarshal.list:35) */
+/* VOID:POINTER,INT (eelmarshal.list:37) */
 extern void eel_marshal_VOID__POINTER_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -281,7 +297,7 @@ extern void eel_marshal_VOID__POINTER_INT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:STRING,POINTER (eelmarshal.list:36) */
+/* VOID:STRING,POINTER (eelmarshal.list:38) */
 extern void eel_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -289,7 +305,7 @@ extern void eel_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:STRING,POINTER,STRING (eelmarshal.list:37) */
+/* VOID:STRING,POINTER,STRING (eelmarshal.list:39) */
 extern void eel_marshal_VOID__STRING_POINTER_STRING (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
@@ -297,7 +313,7 @@ extern void eel_marshal_VOID__STRING_POINTER_STRING (GClosure     *closure,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);
 
-/* VOID:STRING,STRING,POINTER,STRING (eelmarshal.list:38) */
+/* VOID:STRING,STRING,POINTER,STRING (eelmarshal.list:40) */
 extern void eel_marshal_VOID__STRING_STRING_POINTER_STRING (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
@@ -305,7 +321,7 @@ extern void eel_marshal_VOID__STRING_STRING_POINTER_STRING (GClosure     *closur
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);
 
-/* VOID:STRING,LONG,LONG,POINTER (eelmarshal.list:39) */
+/* VOID:STRING,LONG,LONG,POINTER (eelmarshal.list:41) */
 extern void eel_marshal_VOID__STRING_LONG_LONG_POINTER (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -313,7 +329,7 @@ extern void eel_marshal_VOID__STRING_LONG_LONG_POINTER (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* VOID:ENUM,FLOAT (eelmarshal.list:40) */
+/* VOID:ENUM,FLOAT (eelmarshal.list:42) */
 extern void eel_marshal_VOID__ENUM_FLOAT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -321,7 +337,7 @@ extern void eel_marshal_VOID__ENUM_FLOAT (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:ENUM,INT (eelmarshal.list:41) */
+/* VOID:ENUM,INT (eelmarshal.list:43) */
 extern void eel_marshal_VOID__ENUM_INT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -329,7 +345,7 @@ extern void eel_marshal_VOID__ENUM_INT (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* VOID:ENUM,INT,BOOLEAN (eelmarshal.list:42) */
+/* VOID:ENUM,INT,BOOLEAN (eelmarshal.list:44) */
 extern void eel_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -337,7 +353,7 @@ extern void eel_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:ENUM,FLOAT,BOOLEAN (eelmarshal.list:43) */
+/* VOID:ENUM,FLOAT,BOOLEAN (eelmarshal.list:45) */
 extern void eel_marshal_VOID__ENUM_FLOAT_BOOLEAN (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -345,7 +361,7 @@ extern void eel_marshal_VOID__ENUM_FLOAT_BOOLEAN (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:VOID (eelmarshal.list:44) */
+/* VOID:VOID (eelmarshal.list:46) */
 #define eel_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
 
 G_END_DECLS
